@@ -51,6 +51,7 @@ class CreditCard(Resource):
         * Braintree.CreditCard.DinersClubInternational
         * Braintree.CreditCard.Discover
         * Braintree.CreditCard.Electron
+        * Braintree.CreditCard.Elo
         * Braintree.CreditCard.JCB
         * Braintree.CreditCard.Laser
         * Braintree.CreditCard.UK_Maestro
@@ -68,6 +69,7 @@ class CreditCard(Resource):
         DinersClubInternational = "Diners Club"
         Discover = "Discover"
         Electron = "Electron"
+        Elo = "Elo"
         JCB = "JCB"
         Laser = "Laser"
         UK_Maestro = "UK Maestro"
@@ -184,14 +186,7 @@ class CreditCard(Resource):
     @staticmethod
     def forward(credit_card_token, receiving_merchant_id):
         """
-        Create a nonce for a credit card in your Braintree vault that can be used by another Braintree merchant.
-
-        A credit card token and a receiving merchant ID are required:
-
-            result = braintree.CreditCard.forward(
-                credit_card.token,
-                "another_merchant_public_id"
-            })
+        This method has been deprecated. Please consider the Grant API instead.
         """
 
         return Configuration.gateway().credit_card.forward(credit_card_token, receiving_merchant_id)
