@@ -24,6 +24,7 @@ class ErrorCodes(object):
         FirstNameIsInvalid = "91819"
         FirstNameIsTooLong = "81805"
         InconsistentCountry = "91815"
+        IsInvalid = "91828"
         LastNameIsInvalid = "91820"
         LastNameIsTooLong = "81806"
         LocalityIsInvalid = "91824"
@@ -107,6 +108,7 @@ class ErrorCodes(object):
         InvalidVenmoSDKPaymentMethodCode = "91727"
         NumberHasInvalidLength = NumberLengthIsInvalid = "81716"
         NumberIsInvalid = "81715"
+        NumberIsProhibited = "81750"
         NumberIsRequired = "81714"
         NumberMustBeTestNumber = "81717"
         PaymentMethodConflict = "81725"
@@ -133,10 +135,12 @@ class ErrorCodes(object):
             UpdateExistingTokenNotAllowed = "91729"
             VerificationAmountCannotBeNegative = "91739"
             VerificationAmountFormatIsInvalid = "91740"
+            VerificationAmountIsTooLarge = "91752"
             VerificationAmountNotSupportedByProcessor = "91741"
             VerificationMerchantAccountIdIsInvalid = "91728"
             VerificationMerchantAccountIsForbidden = "91743"
             VerificationMerchantAccountIsSuspended = "91742"
+            VerificationMerchantAccountCannotBeSubMerchantAccount = "91755"
 
 
     class Customer(object):
@@ -168,6 +172,37 @@ class ErrorCodes(object):
         PhoneFormatIsInvalid = "92202"
         UrlFormatIsInvalid = "92206"
 
+    class Dispute(object):
+        CanOnlyAddEvidenceToOpenDispute = "95701"
+        CanOnlyRemoveEvidenceFromOpenDispute = "95702"
+        CanOnlyAddEvidenceDocumentToDispute = "95703"
+        CanOnlyAcceptOpenDispute = "95704"
+        CanOnlyFinalizeOpenDispute = "95705"
+        CanOnlyCreateEvidenceWithValidCategory = "95706"
+        EvidenceContentDateInvalid = "95707"
+        EvidenceContentTooLong = "95708"
+        EvidenceContentARNTooLong = "95709"
+        EvidenceContentPhoneTooLong = "95710"
+        EvidenceCategoryTextOnly = "95711"
+        EvidenceCategoryDocumentOnly = "95712"
+        EvidenceCategoryNotForReasonCode = "95713"
+        EvidenceCategoryDuplicate = "95714"
+        EvidenceContentEmailInvalid = "95715"
+
+        DigitalGoodsMissingEvidence = "95720"
+        DigitalGoodsMissingDownloadDate = "95721"
+        NonDisputedPriorTransactionEvidenceMissingARN = "95722"
+        NonDisputedPriorTransactionEvidenceMissingDate = "95723"
+        RecurringTransactionEvidenceMissingDate = "95724"
+        RecurringTransactionEvidenceMissingARN = "95725"
+        ValidEvidenceRequiredToFinalize = "95726"
+
+    class DocumentUpload(object):
+        KindIsInvalid = "84901"
+        FileIsTooLarge = "84902"
+        FileTypeIsInvalid = "84903"
+        FileIsMalformedOrEncrypted = "84904"
+
     class Merchant(object):
         CountryCannotBeBlank = "83603"
         CountryCodeAlpha2IsInvalid = "93607"
@@ -178,10 +213,17 @@ class ErrorCodes(object):
         CountryCodeNumericIsNotAccepted = "93608"
         CountryNameIsInvalid = "93611"
         CountryNameIsNotAccepted = "93610"
+        CurrenciesAreInvalid = "93614"
         EmailFormatIsInvalid = "93602"
         EmailIsRequired = "83601"
         InconsistentCountry = "93612"
         PaymentMethodsAreInvalid = "93613"
+        PaymentMethodsAreNotAllowed = "93615"
+        MerchantAccountExistsForCurrency = "93616"
+        CurrencyIsRequired = "93617"
+        CurrencyIsInvalid = "93618"
+        NoMerchantAccounts = "93619"
+        MerchantAccountExistsForId = "93620"
 
     class MerchantAccount(object):
         IdFormatIsInvalid = "82603"
@@ -290,6 +332,17 @@ class ErrorCodes(object):
         InvalidRequest = "93804"
         UnsupportedGrantType = "93805"
 
+    class Verification(object):
+        class Options(object):
+            AmountCannotBeNegative = "94201"
+            AmountFormatIsInvalid = "94202"
+            AmountIsTooLarge = "94207"
+            AmountNotSupportedByProcessor = "94203"
+            MerchantAccountIdIsInvalid = "94204"
+            MerchantAccountIsSuspended = "94205"
+            MerchantAccountIsForbidden = "94206"
+            MerchantAccountCannotBeSubMerchantAccount = "94208"
+
     class PaymentMethod(object):
         CannotForwardPaymentMethodType = "93106"
         PaymentMethodParamsAreRequired = "93101"
@@ -300,11 +353,15 @@ class ErrorCodes(object):
         PaymentMethodNonceConsumed = "93107"
         PaymentMethodNonceUnknown = "93108"
         PaymentMethodNonceLocked = "93109"
+        PaymentMethodNoLongerSupported = "93117"
         AuthExpired = "92911"
         CannotHaveFundingSourceWithoutAccessToken = "92912"
         InvalidFundingSourceSelection = "92913"
         CannotUpdatePayPalAccountUsingPaymentMethodNonce = "92914"
 
+        class Options(object):
+            UsBankAccountVerificationMethodIsInvalid = "93121"
+
     class PayPalAccount(object):
         CannotHaveBothAccessTokenAndConsentCode = "82903"
         CannotVaultOneTimeUsePayPalAccount = "82902"
@@ -408,6 +465,7 @@ class ErrorCodes(object):
     class Transaction(object):
         AmountCannotBeNegative = "81501"
         AmountDoesNotMatch3DSecureAmount = "91585"
+        AmountDoesNotMatchIdealPaymentAmount = "915144"
         AmountIsInvalid = AmountFormatIsInvalid = "81503"
         AmountIsRequired = "81502"
         AmountIsTooLarge = "81528"
@@ -416,6 +474,7 @@ class ErrorCodes(object):
         CannotBeVoided = "91504"
         CannotCancelRelease = "91562"
         CannotCloneCredit = "91543"
+        CannotCloneMarketplaceTransaction = "915137"
         CannotCloneTransactionWithPayPalAccount = "91573"
         CannotCloneTransactionWithVaultCreditCard = "91540"
         CannotCloneUnsuccessfulTransaction = "91542"
@@ -431,6 +490,7 @@ class ErrorCodes(object):
         CannotSimulateTransactionSettlement = "91575"
         CannotSubmitForPartialSettlement = "915103"
         CannotSubmitForSettlement = "91507"
+        CannotUpdateTransactionDetailsNotSubmittedForSettlement = "915129"
         ChannelIsTooLong = "91550"
         ChannelIsTooLong = "91550"
         CreditCardIsRequired = "91508"
@@ -439,14 +499,33 @@ class ErrorCodes(object):
         CustomerDefaultPaymentMethodCardTypeIsNotAccepted = "81509"
         CustomerDoesNotHaveCreditCard = "91511"
         CustomerIdIsInvalid = "91510"
+        FailedAuthAdjustmentAllowRetry = "95603"
+        FailedAuthAdjustmentHardDecline = "95602"
+        FinalAuthSubmitForSettlementForDifferentAmount = "95601"
         HasAlreadyBeenRefunded = "91512"
+        IdealPaymentNotComplete = "815141"
+        IdealPaymentsCannotBeVaulted = "915150"
+        PaymentInstrumentWithExternalVaultIsInvalid = "915176"
+        DiscountAmountFormatIsInvalid = "915159"
+        DiscountAmountCannotBeNegative = "915160"
+        DiscountAmountIsTooLarge = "915161"
+        ShippingAmountFormatIsInvalid = "915162"
+        ShippingAmountCannotBeNegative = "915163"
+        ShippingAmountIsTooLarge = "915164"
+        ShipsFromPostalCodeIsTooLong = "915165"
+        ShipsFromPostalCodeIsInvalid = "915166"
+        ShipsFromPostalCodeInvalidCharacters = "915167"
         MerchantAccountDoesNotMatch3DSecureMerchantAccount = "91584"
+        MerchantAccountDoesNotMatchIdealPaymentMerchantAccount = "915143"
         MerchantAccountDoesNotSupportMOTO = "91558"
         MerchantAccountDoesNotSupportRefunds = "91547"
+        MerchantAccountIdDoesNotMatchSubscription = "915180"
         MerchantAccountIdIsInvalid = "91513"
         MerchantAccountIsSusped = "91514" # Deprecated
         MerchantAccountIsSuspended = "91514"
         MerchantAccountNameIsInvalid = "91513" # Deprecated
+        OrderIdDoesNotMatchIdealPaymentOrderId = "91503"
+        OrderIdIsRequiredWithIdealPayment = "91502"
         OrderIdIsTooLong = "91501"
         PayPalAuthExpired = "91579"
         PayPalNotEnabled = "91576"
@@ -471,6 +550,7 @@ class ErrorCodes(object):
         ProcessorDoesNotSupportPartialSettlement = "915102"
         ProcessorDoesNotSupportUpdatingOrderId = "915107"
         ProcessorDoesNotSupportUpdatingDescriptor = "915108"
+        ProcessorDoesNotSupportUpdatingTransactionDetails = "915130"
         ProcessorDoesNotSupportVoiceAuthorizations = "91545"
         PurchaseOrderNumberIsInvalid = "91548"
         PurchaseOrderNumberIsTooLong = "91537"
@@ -494,9 +574,25 @@ class ErrorCodes(object):
         ThreeDSecureAuthenticationFailed = "81571"
         ThreeDSecureTokenIsInvalid = "91568"
         ThreeDSecureTransactionDataDoesntMatchVerify = "91570"
+        ThreeDSecureEciFlagIsRequired = "915113"
+        ThreeDSecureCavvIsRequired = "915116"
+        ThreeDSecureXidIsRequired = "915115"
+        ThreeDSecureEciFlagIsInvalid = "915114"
+        ThreeDSecureMerchantAccountDoesNotSupportCardType = "915131"
+        TooManyLineItems = "915157"
+        LineItemsExpected = "915158"
         TypeIsInvalid = "91523"
         TypeIsRequired = "91524"
         UnsupportedVoiceAuthorization = "91539"
+        UsBankAccountNonceMustBePlaidVerified = "915171"
+        UsBankAccountNotVerified = "915172"
+        TransactionSourceIsInvalid = "915133"
+
+        class ExternalVault(object):
+            StatusIsInvalid = "915175"
+            StatusWithPreviousNetworkTransactionIdIsInvalid = "915177"
+            CardTypeIsInvalid = "915178"
+            PreviousNetworkTransactionIdIsInvalid = "915179"
 
         class Options(object):
             SubmitForSettlementIsRequiredForCloning = "91544"
@@ -508,7 +604,7 @@ class ErrorCodes(object):
                 CustomFieldTooLong = "91580"
 
         class Industry(object):
-            IndustryTypeIsInvalid = "93401" 
+            IndustryTypeIsInvalid = "93401"
 
             class Lodging(object):
                 EmptyData = "93402"
@@ -524,4 +620,86 @@ class ErrorCodes(object):
                 DepartureDateIsInvalid = "93411"
                 LodgingCheckInDateIsInvalid = "93412"
                 LodgingCheckOutDateIsInvalid = "93413"
+            class TravelFlight(object):
+                EmptyData = "93414"
+                UnknownDataField = "93415"
+                CustomerCodeIsTooLong = "93416"
+                FareAmountCannotBeNegative = "93417"
+                FareAmountFormatIsInvalid = "93418"
+                FareAmountIsTooLarge = "93419"
+                FeeAmountCannotBeNegative = "93420"
+                FeeAmountFormatIsInvalid = "93421"
+                FeeAmountIsTooLarge = "93422"
+                IssuedDateFormatIsInvalid = "93423"
+                IssuingCarrierCodeIsTooLong = "93424"
+                PassengerMiddleInitialIsTooLong = "93425"
+                RestrictedTicketIsRequired = "93426"
+                TaxAmountCannotBeNegative = "93427"
+                TaxAmountFormatIsInvalid = "93428"
+                TaxAmountIsTooLarge = "93429"
+                TicketNumberIsTooLong = "93430"
+                LegsExpected = "93431"
+                TooManyLegs = "93432"
 
+            class Leg(object):
+                class TravelFlight(object):
+                    ArrivalAirportCodeIsTooLong = "96301"
+                    ArrivalTimeFormatIsInvalid = "96302"
+                    CarrierCodeIsTooLong = "96303"
+                    ConjunctionTicketIsTooLong = "96304"
+                    CouponNumberIsTooLong = "96305"
+                    DepartureAirportCodeIsTooLong = "96306"
+                    DepartureTimeFormatIsInvalid = "96307"
+                    ExchangeTicketIsTooLong = "96308"
+                    FareAmountCannotBeNegative = "96309"
+                    FareAmountFormatIsInvalid = "96310"
+                    FareAmountIsTooLarge = "96311"
+                    FareBasisCodeIsTooLong = "96312"
+                    FeeAmountCannotBeNegative = "96313"
+                    FeeAmountFormatIsInvalid = "96314"
+                    FeeAmountIsTooLarge = "96315"
+                    ServiceClassIsTooLong = "96316"
+                    TaxAmountCannotBeNegative = "96317"
+                    TaxAmountFormatIsInvalid = "96318"
+                    TaxAmountIsTooLarge = "96319"
+                    TicketNumberIsTooLong = "96320"
+
+        class LineItem(object):
+            CommodityCodeIsTooLong = "95801"
+            DescriptionIsTooLong = "95803"
+            DiscountAmountFormatIsInvalid = "95804"
+            DiscountAmountIsTooLarge = "95805"
+            DiscountAmountMustBeGreaterThanZero = "95806" # Deprecated as the amount may be zero.
+            DiscountAmountCannotBeNegative = "95806"
+            KindIsInvalid = "95807"
+            KindIsRequired = "95808"
+            NameIsRequired = "95822"
+            NameIsTooLong = "95823"
+            ProductCodeIsTooLong = "95809"
+            QuantityFormatIsInvalid = "95810"
+            QuantityIsRequired = "95811"
+            QuantityIsTooLarge = "95812"
+            TotalAmountFormatIsInvalid = "95813"
+            TotalAmountIsRequired = "95814"
+            TotalAmountIsTooLarge = "95815"
+            TotalAmountMustBeGreaterThanZero = "95816"
+            UnitAmountFormatIsInvalid = "95817"
+            UnitAmountIsRequired = "95818"
+            UnitAmountIsTooLarge = "95819"
+            UnitAmountMustBeGreaterThanZero = "95820"
+            UnitOfMeasureIsTooLarge = "95821"
+            UnitTaxAmountFormatIsInvalid = "95824"
+            UnitTaxAmountIsTooLarge = "95825"
+            UnitTaxAmountMustBeGreaterThanZero = "95826" # Deprecated as the amount may be zero.
+            UnitTaxAmountCannotBeNegative = "95826"
+            TaxAmountFormatIsInvalid = "95827"
+            TaxAmountIsTooLarge = "95828"
+            TaxAmountCannotBeNegative = "95829"
+
+    class UsBankAccountVerification(object):
+        NotConfirmable = "96101"
+        MustBeMicroTransfersVerification = "96102"
+        AmountsDoNotMatch = "96103"
+        TooManyConfirmationAttempts = "96104"
+        UnableToConfirmDepositAmounts = "96105"
+        InvalidDepositAmounts = "96106"
