@@ -1,6 +1,10 @@
 from braintree.util.crypto import Crypto
 from braintree.webhook_notification import WebhookNotification
-import base64
+import sys
+if sys.version_info[0] == 2:
+    from base64 import encodestring as encodebytes
+else:
+    from base64 import encodebytes
 from datetime import datetime
 
 class WebhookTestingGateway(object):
@@ -8,21 +12,27 @@ class WebhookTestingGateway(object):
         self.gateway = gateway
         self.config = gateway.config
 
-    def sample_notification(self, kind, id):
-        payload = base64.encodestring(self.__sample_xml(kind, id))
+    def sample_notification(self, kind, id, source_merchant_id=None):
+        payload = encodebytes(self.__sample_xml(kind, id, source_merchant_id))
         hmac_payload = Crypto.sha1_hmac_hash(self.gateway.config.private_key, payload)
         signature = "%s|%s" % (self.gateway.config.public_key, hmac_payload)
         return {'bt_signature': signature, 'bt_payload': payload}
 
-    def __sample_xml(self, kind, id):
+    def __sample_xml(self, kind, id, source_merchant_id):
         timestamp = datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%SZ")
+
+        source_merchant_id_xml = ''
+        if source_merchant_id is not None:
+            source_merchant_id_xml = '<source-merchant-id>%s</source-merchant-id>' % source_merchant_id
+
         sample_xml = """
             <notification>
                 <timestamp type="datetime">%s</timestamp>
                 <kind>%s</kind>
+                %s
                 <subject>%s</subject>
             </notification>
-        """ % (timestamp, kind, self.__subject_sample_xml(kind, id))
+        """ % (timestamp, kind, source_merchant_id_xml, self.__subject_sample_xml(kind, id))
         return sample_xml.encode('utf-8')
 
     def __subject_sample_xml(self, kind, id):
@@ -48,6 +58,8 @@ class WebhookTestingGateway(object):
             return self.__partner_merchant_disconnected_sample_xml()
         elif kind == WebhookNotification.Kind.PartnerMerchantDeclined:
             return self.__partner_merchant_declined_sample_xml()
+        elif kind == WebhookNotification.Kind.OAuthAccessRevoked:
+            return self.__oauth_access_revocation_sample_xml(id)
         elif kind == WebhookNotification.Kind.DisbursementException:
             return self.__disbursement_exception_sample_xml(id)
         elif kind == WebhookNotification.Kind.Disbursement:
@@ -60,12 +72,18 @@ class WebhookTestingGateway(object):
             return self.__dispute_won_sample_xml(id)
         elif kind == WebhookNotification.Kind.SubscriptionChargedSuccessfully:
             return self.__subscription_charged_successfully_sample_xml(id)
+        elif kind == WebhookNotification.Kind.SubscriptionChargedUnsuccessfully:
+            return self.__subscription_charged_unsuccessfully_sample_xml(id)
         elif kind == WebhookNotification.Kind.AccountUpdaterDailyReport:
             return self.__account_updater_daily_report_sample_xml()
         elif kind == WebhookNotification.Kind.IdealPaymentComplete:
             return self.__ideal_payment_complete_sample_xml(id)
         elif kind == WebhookNotification.Kind.IdealPaymentFailed:
             return self.__ideal_payment_failed_sample_xml(id)
+        elif kind == WebhookNotification.Kind.GrantedPaymentInstrumentUpdate:
+            return self.__granted_payment_instrument_update()
+        elif kind == WebhookNotification.Kind.LocalPaymentCompleted:
+            return self.__local_payment_completed()
         else:
             return self.__subscription_sample_xml(id)
 
@@ -430,6 +448,7 @@ class WebhookTestingGateway(object):
                 <id>%s</id>
                 <transactions type="array">
                     <transaction>
+                        <id>%s</id>
                         <status>submitted_for_settlement</status>
                         <amount>49.99</amount>
                         <tax_amount></tax_amount>
@@ -438,7 +457,24 @@ class WebhookTestingGateway(object):
                 <add_ons type="array"></add_ons>
                 <discounts type="array"></discounts>
             </subscription>
-        """ % id
+        """ % (id, id)
+
+    def __subscription_charged_unsuccessfully_sample_xml(self, id):
+        return """
+            <subscription>
+                <id>%s</id>
+                <transactions type="array">
+                    <transaction>
+                        <id>%s</id>
+                        <status>failed</status>
+                        <amount>49.99</amount>
+                        <tax_amount></tax_amount>
+                    </transaction>
+                </transactions>
+                <add_ons type="array"></add_ons>
+                <discounts type="array"></discounts>
+            </subscription>
+        """ % (id, id)
 
     def __merchant_account_approved_sample_xml(self, id):
         return """
@@ -522,6 +558,14 @@ class WebhookTestingGateway(object):
             </partner-merchant>
             """
 
+    def __oauth_access_revocation_sample_xml(self, id):
+        return """
+            <oauth-application-revocation>
+                <merchant-id>%s</merchant-id>
+                <oauth-application-client-id>oauth_application_client_id</oauth-application-client-id>
+            </oauth-application-revocation>
+            """ % id
+
     def __account_updater_daily_report_sample_xml(self):
         return """
             <account-updater-daily-report>
@@ -559,3 +603,29 @@ class WebhookTestingGateway(object):
                 <ideal-transaction-id>1234567890</ideal-transaction-id>
             </ideal-payment>
             """ % id
+
+    def __granted_payment_instrument_update(self):
+        return """
+            <granted-payment-instrument-update>
+                <grant-owner-merchant-id>vczo7jqrpwrsi2px</grant-owner-merchant-id>
+                <grant-recipient-merchant-id>cf0i8wgarszuy6hc</grant-recipient-merchant-id>
+                <payment-method-nonce>
+                    <nonce>ee257d98-de40-47e8-96b3-a6954ea7a9a4</nonce>
+                    <consumed type="boolean">false</consumed>
+                    <locked type="boolean">false</locked>
+                </payment-method-nonce>
+                <token>abc123z</token>
+                <updated-fields type="array">
+                    <item>expiration-month</item>
+                    <item>expiration-year</item>
+                </updated-fields>
+            </granted-payment-instrument-update>
+            """
+
+    def __local_payment_completed(self):
+        return """
+            <local-payment>
+                <payment-id>a-payment-id</payment-id>
+                <payer-id>a-payer-id</payer-id>
+            </local-payment>
+            """
