@@ -55,6 +55,8 @@ class TestPaymentMethodGateway(unittest.TestCase):
             "expiration_year",
             "number",
             "payment_method_nonce",
+            "paypal_refresh_token",
+            "paypal_vault_without_upgrade",
             "token",
             {
                 "billing_address": Address.create_signature()},
@@ -62,6 +64,7 @@ class TestPaymentMethodGateway(unittest.TestCase):
                 "options": [
                     "fail_on_duplicate_payment_method",
                     "make_default",
+                    "us_bank_account_verification_method",
                     "verification_merchant_account_id",
                     "verify_card",
                     "verification_amount",
@@ -78,6 +81,23 @@ class TestPaymentMethodGateway(unittest.TestCase):
                             "custom_field",
                             "description",
                             "amount",
+                            {
+                                "shipping":[
+                                    "company",
+                                    "country_code_alpha2",
+                                    "country_code_alpha3",
+                                    "country_code_numeric",
+                                    "country_name",
+                                    "customer_id",
+                                    "extended_address",
+                                    "first_name",
+                                    "last_name",
+                                    "locality",
+                                    "postal_code",
+                                    "region",
+                                    "street_address"
+                                ]
+                            },
                         ]
                     },
                 ]
@@ -106,6 +126,7 @@ class TestPaymentMethodGateway(unittest.TestCase):
             {
                 "options": [
                     "make_default",
+                    "us_bank_account_verification_method",
                     "verify_card",
                     "verification_amount",
                     "verification_merchant_account_id",
