@@ -425,6 +425,23 @@ class TestWebhooks(unittest.TestCase):
         self.assertEqual("submitted_for_settlement", transaction.status)
         self.assertEqual(Decimal("49.99"), transaction.amount)
 
+    def test_builds_notification_for_subscription_charged_unsuccessfully(self):
+        sample_notification = WebhookTesting.sample_notification(
+            WebhookNotification.Kind.SubscriptionChargedUnsuccessfully,
+            "my_id"
+        )
+
+        notification = WebhookNotification.parse(sample_notification['bt_signature'], sample_notification['bt_payload'])
+
+        self.assertEqual(WebhookNotification.Kind.SubscriptionChargedUnsuccessfully, notification.kind)
+        self.assertEqual("my_id", notification.subscription.id)
+        self.assertTrue(len(notification.subscription.transactions) == 1)
+
+        transaction = notification.subscription.transactions.pop()
+
+        self.assertEqual("failed", transaction.status)
+        self.assertEqual(Decimal("49.99"), transaction.amount)
+
     def test_builds_notification_for_check(self):
         sample_notification = WebhookTesting.sample_notification(
             WebhookNotification.Kind.Check,
@@ -496,3 +513,17 @@ class TestWebhooks(unittest.TestCase):
         self.assertEqual("ee257d98-de40-47e8-96b3-a6954ea7a9a4", update.payment_method_nonce)
         self.assertEqual("abc123z", update.token)
         self.assertEqual(["expiration-month", "expiration-year"], update.updated_fields)
+
+    def test_local_payment_completed_webhook(self):
+        sample_notification = WebhookTesting.sample_notification(
+            WebhookNotification.Kind.LocalPaymentCompleted,
+            "my_id"
+        )
+
+        notification = WebhookNotification.parse(sample_notification["bt_signature"], sample_notification["bt_payload"])
+        local_payment_completed = notification.local_payment_completed
+
+        self.assertEqual(WebhookNotification.Kind.LocalPaymentCompleted, notification.kind)
+        self.assertEqual("a-payment-id", local_payment_completed.payment_id)
+        self.assertEqual("a-payer-id", local_payment_completed.payer_id)
+
